# -*- coding: utf-8 -*-

# Copyright 2015-2016 Mir Calculate. http://www.calculate-linux.org
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

class EmergeMark:
    Schedule = "schedule"
    Premerge = "check updates"
    PythonUpdater = "update python modules"
    PerlCleaner = "update perl modules"
    KernelModules = "update kernel modules"
    Depclean = "depclean"
    XorgModules = "update xorg modules"
    PreservedLibs = "update preserved libs"
    RevdepRebuild = "revdep rebuild"
    Prelink = "prelink"
    Automagic = "check for auto depends"
    SaveTag = "save latest calculate update tag"
